﻿// Print Workingsteps in a STEP-NC Process using VB
// ========================================
//
// This C# project calls the STEP-NC API using the .NET interface.  It
// prints all workingsteps and workplans in a machining program.
//
// You can find more examples and other documentation at:
//
//      http://www.steptools.com/support/
//

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using STEPNCLib;

namespace cursor_steps_cs
{
    class Program
    {
	static void Main(string[] args)
	{
	    Finder finder = new Finder();
	    Adaptive ctl = new Adaptive();

	    // Read a STEP-NC file
	    finder.Open238("C:/Program Files (x86)/STEP Tools/STEP-NC Machine/examples/boxy_renton_signed.stpnc");

	    // Start traversing the process within the file.   Uses the active data from finder.
	    ctl.StartProject();

	    // Select only workplan start/stop, and individual workingsteps
	    ctl.SetWantedAll(false);
	    ctl.SetWanted(Adaptive.CtlEvent.EXEC_WORKPLAN_START);
	    ctl.SetWanted(Adaptive.CtlEvent.EXEC_WORKPLAN_END);
	    ctl.SetWanted(Adaptive.CtlEvent.OPERATION_START);

	    while (ctl.Next() != Adaptive.CtlEvent.DONE)
	    {
		long id;
		switch (ctl.Event())
		{
		    case Adaptive.CtlEvent.EXEC_WORKPLAN_START:
			id = ctl.GetActiveWorkplan();
			Console.WriteLine("STARTING WORKPLAN #{0} [{1}]", id, finder.GetExecutableName(id));
			break;
		    case Adaptive.CtlEvent.EXEC_WORKPLAN_END:
			Console.WriteLine("ENDING WORKPLAN #{0}",ctl.GetActiveWorkplan());
 			break;

		    case Adaptive.CtlEvent.OPERATION_START:
			id = ctl.GetActiveExec(); 
			Console.WriteLine("STARTING OPERATION #{0} (workstep #{1}) [{2}]", 
			    ctl.GetActiveOperation(), id, finder.GetExecutableName(id));		
			break;

		    default:
			Console.WriteLine("UNEXPECTED EVENT");
 			break;

		}
	    }
	}
    }
}
